@@ -1,58 +1,69 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0" language="fi_FI">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="fi_FI" version="2.0">
 <defaultcodec>UTF-8</defaultcodec>
 <context>
     <name>AboutView</name>
     <message>
+        <location filename="../src/AboutView.cpp" line="21"/>
         <source>There&apos;s life outside the browser!</source>
         <translation>Selaimen ulkopuolellakin on elämää!</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="22"/>
         <source>Version %1</source>
         <translation>Versionumero: %1</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="25"/>
         <source>%1 is Free Software but its development takes precious time.</source>
         <translation>%1 on ilmainen ohjelma,mutta sen kehittäminen vie kallista aika.</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="26"/>
         <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
         <translation>Voit tukea  %2n kehityksen jatkumista tekemällä &lt;a href=&apos;%1&apos;&gt;lahjoituksen&lt;/a&gt;.</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="29"/>
         <source>Report bugs and send in your ideas to %1</source>
         <translation>Ilmoita bugit ja kerro ideasi osoitteeseen %1</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="33"/>
         <source>Icon designed by %1.</source>
         <translation>Kuvakkeen suunnitteli %1.</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="34"/>
         <source>Compact mode contributed by %1.</source>
         <translation>Kompaktin tilan teki %1.</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="35"/>
         <source>HTTP proxy support contributed by %1.</source>
         <translation>HTTP-välityspalvelintuen teki %1.</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="38"/>
         <source>Translated by %1</source>
         <translation>Käännöksen teki %1</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="66"/>
         <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
         <translation>Julkaistu &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt; -lisenssillä</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="78"/>
         <source>&amp;Close</source>
         <translation>&amp;Sulje</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.h" line="18"/>
         <source>About</source>
         <translation>Tietoja</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.h" line="20"/>
         <source>What you always wanted to know about %1 and never dared to ask</source>
         <translation>Mitä olet aina halunnut tietää %1sta, muttet ole koskaan kehdannut kysyä</translation>
     </message>
@@ -60,6 +71,7 @@
 <context>
     <name>ClearButton</name>
     <message>
+        <location filename="../src/searchlineedit.cpp" line="56"/>
         <source>Clear</source>
         <translation>Tyhjennä</translation>
     </message>
@@ -67,87 +79,103 @@
 <context>
     <name>DownloadItem</name>
     <message>
+        <location filename="../src/downloaditem.cpp" line="295"/>
         <source>bytes</source>
         <translation>tavua</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="298"/>
         <source>KB</source>
         <translation>Kt</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="301"/>
         <source>MB</source>
         <translation>Mt</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="317"/>
         <source>bytes/sec</source>
         <translation>tavua/sekunnissa</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="320"/>
         <source>KB/sec</source>
         <translation>Kt/s</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="323"/>
         <source>MB/sec</source>
         <translation>Mt/s</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="329"/>
         <source>seconds</source>
         <translation>sekunttia</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="332"/>
         <source>minutes</source>
         <translation>minuuttia</translation>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="335"/>
         <source>%4 %5 remaining</source>
         <translation>%4 %5 jäljellä</translation>
     </message>
 </context>
 <context>
     <name>DownloadManager</name>
-    <message numerus="yes">
-        <source>%n Download(s)</source>
-        <translation>
-            <numerusform>%n Lataus(ta)</numerusform>
-            <numerusform></numerusform>
-        </translation>
-    </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="47"/>
         <source>This is just the demo version of %1.</source>
         <translation>Tämä on vain kokeilu versio %1sta.</translation>
     </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="49"/>
         <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
         <translation>Voit ladata vain videoita jotka ovat lyhyempiä kuin %1 minuuttia, jotta voit testata lataus ominaisuutta.</translation>
     </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="53"/>
         <source>Continue</source>
         <translation>Jatka</translation>
     </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="54"/>
         <source>Get the full version</source>
         <translation>Hanki täysi versio</translation>
     </message>
+    <message numerus="yes">
+        <location filename="../src/downloadmanager.cpp" line="126"/>
+        <source>%n Download(s)</source>
+        <translation><numerusform>%n Lataus(ta)</numerusform><numerusform></numerusform></translation>
+    </message>
 </context>
 <context>
     <name>DownloadSettings</name>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="14"/>
         <source>Change location...</source>
         <translation>Vaihda sijaintia...</translation>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="38"/>
         <source>Choose the download location</source>
         <translation>Valitse latausten sijainti</translation>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="49"/>
         <source>Download location changed.</source>
         <translation>Lataus sijaintia on muutettu.</translation>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="51"/>
         <source>Current downloads will still go in the previous location.</source>
         <translation>Nykyiset lataukset menevät vanhaan sijaintiin.</translation>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="63"/>
         <source>Downloading to: %1</source>
         <translation>Ladataan kansioon: %1</translation>
     </message>
@@ -155,6 +183,8 @@
 <context>
     <name>DownloadView</name>
     <message>
+        <location filename="../src/downloadview.cpp" line="18"/>
+        <location filename="../src/downloadview.h" line="22"/>
         <source>Downloads</source>
         <translation>Lataukset</translation>
     </message>
@@ -162,50 +192,62 @@
 <context>
     <name>GlobalShortcuts</name>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="16"/>
         <source>Play</source>
         <translation>Toista</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="17"/>
         <source>Pause</source>
         <translation>Keskeytä</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="18"/>
         <source>Play/Pause</source>
         <translation>Toista/Keskeytä</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="19"/>
         <source>Stop</source>
         <translation>Pysäytä</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="20"/>
         <source>Stop playing after current track</source>
         <translation>Pysäytä toisto nykyisen kappaleen jälkeen</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="21"/>
         <source>Next track</source>
         <translation>Seuraava kappale</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="22"/>
         <source>Previous track</source>
         <translation>Edellinen kappale</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="23"/>
         <source>Increase volume</source>
         <translation>Lisää äänen voimakkuutta</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="24"/>
         <source>Decrease volume</source>
         <translation>Vähennä äänen voimakkuutta</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="25"/>
         <source>Mute</source>
         <translation>Mykistä</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="26"/>
         <source>Seek forward</source>
         <translation>Kelaa eteenpäin</translation>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="27"/>
         <source>Seek backward</source>
         <translation>Kelaa taaksepäin</translation>
     </message>
@@ -213,18 +255,22 @@
 <context>
     <name>ListModel</name>
     <message>
+        <location filename="../src/ListModel.cpp" line="47"/>
         <source>Searching...</source>
         <translation>Etsitään...</translation>
     </message>
     <message>
+        <location filename="../src/ListModel.cpp" line="48"/>
         <source>Show %1 More</source>
         <translation>Näytä %1 lisää</translation>
     </message>
     <message>
+        <location filename="../src/ListModel.cpp" line="49"/>
         <source>No videos</source>
         <translation>Ei videoita</translation>
     </message>
     <message>
+        <location filename="../src/ListModel.cpp" line="50"/>
         <source>No more videos</source>
         <translation>Ei enempää videoita</translation>
     </message>
@@ -232,6 +278,7 @@
 <context>
     <name>LoadingWidget</name>
     <message>
+        <location filename="../src/loadingwidget.cpp" line="71"/>
         <source>Error</source>
         <translation>Virhe</translation>
     </message>
@@ -239,305 +286,375 @@
 <context>
     <name>MainWindow</name>
     <message>
+        <location filename="../src/MainWindow.cpp" line="105"/>
         <source>&amp;Stop</source>
         <translation>&amp;Pysäytä</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="106"/>
         <source>Stop playback and go back to the search view</source>
         <translation>Pysäytä toisto ja palaa hakuruutuun</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="112"/>
         <source>S&amp;kip</source>
         <translation>&amp;Hyppää yli</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="113"/>
         <source>Skip to the next video</source>
         <translation>Siirry seuraavaan videoon</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="119"/>
+        <location filename="../src/MainWindow.cpp" line="644"/>
         <source>&amp;Pause</source>
         <translation>&amp;Keskeytä</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="120"/>
+        <location filename="../src/MainWindow.cpp" line="645"/>
         <source>Pause playback</source>
         <translation>Keskeytä toisto</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="126"/>
+        <location filename="../src/MainWindow.cpp" line="728"/>
         <source>&amp;Full Screen</source>
         <translation>&amp;Kokoruutu</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="127"/>
         <source>Go full screen</source>
         <translation>Siirry kokoruututilaan</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="136"/>
         <source>&amp;Compact mode</source>
         <translation>&amp;Kompakti tila</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="137"/>
         <source>Hide the playlist and the toolbar</source>
         <translation>Piilota toistolista sekä työkalupalkki</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="145"/>
         <source>Open the &amp;YouTube page</source>
         <translation>Avaa &amp;Youtube -sivu</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="146"/>
         <source>Go to the YouTube video page and pause playback</source>
         <translation>Keskeytä toisto ja mene videon YouTube -sivulle</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="152"/>
         <source>Copy the YouTube &amp;link</source>
         <translation>Kopio YouTube -&amp;linkki</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="153"/>
         <source>Copy the current video YouTube link to the clipboard</source>
         <translation>Kopio nykyisen videon YouTube -linkki leikepöydälle</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="159"/>
         <source>Copy the video stream &amp;URL</source>
         <translation>Kopioi videovirran osoite (&amp;URL)</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="160"/>
         <source>Copy the current video stream URL to the clipboard</source>
         <translation>Kopioi nykyisen videvirran osoite (URL) leikepöydälle</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="166"/>
         <source>&amp;Remove</source>
         <translation>&amp;Poista</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="167"/>
         <source>Remove the selected videos from the playlist</source>
         <translation>Poista valitut videot toistolistalta</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="173"/>
         <source>Move &amp;Up</source>
         <translation>Siirrä &amp;Ylös</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="174"/>
         <source>Move up the selected videos in the playlist</source>
         <translation>Siirrä valitut videot ylemmäksi toistolistalla</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="180"/>
         <source>Move &amp;Down</source>
         <translation>Sirrä &amp;Alas</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="181"/>
         <source>Move down the selected videos in the playlist</source>
         <translation>Siirrä valitut videot alemmaksi toistolistalla</translation>
     </message>
     <message>
-        <source>&amp;Clear recent keywords</source>
-        <translation type="obsolete">&amp;Poista viimeisimmät hakusanat</translation>
+        <location filename="../src/MainWindow.cpp" line="187"/>
+        <source>&amp;Clear recent searches</source>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="192"/>
         <source>Clear the search history. Cannot be undone.</source>
         <translation>Tyhjennä hakuhistoria. Tätä toimintoa ei voi kumota.</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="197"/>
         <source>&amp;Quit</source>
         <translation>&amp;Lopeta</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="199"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="200"/>
         <source>Bye</source>
         <translation>Näkemiin</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="204"/>
         <source>&amp;Website</source>
         <translation>&amp;Nettisivusto</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="206"/>
         <source>%1 on the Web</source>
         <translation>%1 netissä</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="210"/>
         <source>Make a &amp;donation</source>
         <translation>Tee &amp;lahjoitus</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="211"/>
         <source>Please support the continued development of %1</source>
         <translation>Tue %1n jatkokehitystä</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="215"/>
         <source>&amp;About</source>
         <translation>&amp;Tietoja</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="217"/>
         <source>Info about %1</source>
         <translation>Tietoja %1sta</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="225"/>
         <source>Search</source>
         <translation>Etsi</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="244"/>
         <source>Mute volume</source>
         <translation>Mykistä ääni</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="246"/>
         <source>Ctrl+M</source>
         <translation>Ctrl+M</translation>
     </message>
     <message>
-        <source>&amp;Application</source>
-        <translation>&amp;Sovellus</translation>
-    </message>
-    <message>
-        <source>&amp;Playlist</source>
-        <translation>&amp;Toistolista</translation>
-    </message>
-    <message>
-        <source>&amp;Video</source>
-        <translation>&amp;Video</translation>
-    </message>
-    <message>
-        <source>&amp;Help</source>
-        <translation>&amp;Apua</translation>
-    </message>
-    <message>
-        <source>Press %1 to raise the volume, %2 to lower it</source>
-        <translation>Paina näppäinyhdistelmää %1 nostaaksesi tai %2 laskeaksesi äänenvoimakkuutta</translation>
-    </message>
-    <message>
-        <source>Opening %1</source>
-        <translation>Avataan kohdetta %1</translation>
-    </message>
-    <message>
-        <source>Fatal error: %1</source>
-        <translation>Kohtalokas virhe: %1</translation>
-    </message>
-    <message>
-        <source>Error: %1</source>
-        <translation>Virhe: %1</translation>
-    </message>
-    <message>
-        <source>&amp;Play</source>
-        <translation>&amp;Toista</translation>
-    </message>
-    <message>
-        <source>Resume playback</source>
-        <translation>Jatka toistoa</translation>
-    </message>
-    <message>
-        <source>Exit &amp;Full Screen</source>
-        <translation>Poistu &amp;kokoruudun tilasta</translation>
-    </message>
-    <message>
-        <source>Remaining time: %1</source>
-        <translation>Aikaa jäljellä: %1</translation>
-    </message>
-    <message>
-        <source>Volume at %1%</source>
-        <translation>Äänentaso: %1%</translation>
-    </message>
-    <message>
-        <source>Volume is muted</source>
-        <translation>Ääni on mykistetty</translation>
-    </message>
-    <message>
-        <source>Volume is unmuted</source>
-        <translation>Ääni ei ole mykistetty</translation>
-    </message>
-    <message>
-        <source>Maximum video definition set to %1</source>
-        <translation>Korkein videonlaatu on rajoitettu tarkkuteen %1</translation>
-    </message>
-    <message>
-        <source>Your privacy is now safe</source>
-        <translation>Yksityisyytesi on nyt turvattu</translation>
-    </message>
-    <message>
+        <location filename="../src/MainWindow.cpp" line="277"/>
+        <location filename="../src/MainWindow.cpp" line="959"/>
         <source>&amp;Downloads</source>
         <translation>&amp;Lataukset</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="278"/>
         <source>Show details about video downloads</source>
         <translation>Näytä tietoja latauksista</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="286"/>
         <source>&amp;Download</source>
         <translation>&amp;Lataa</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="287"/>
         <source>Download the current video</source>
         <translation>Lataa nykyinen video</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="328"/>
+        <source>&amp;Application</source>
+        <translation>&amp;Sovellus</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="336"/>
+        <source>&amp;Playlist</source>
+        <translation>&amp;Toistolista</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="343"/>
+        <source>&amp;Video</source>
+        <translation>&amp;Video</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="362"/>
+        <source>&amp;Help</source>
+        <translation>&amp;Apua</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="439"/>
+        <source>Press %1 to raise the volume, %2 to lower it</source>
+        <translation>Paina näppäinyhdistelmää %1 nostaaksesi tai %2 laskeaksesi äänenvoimakkuutta</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="578"/>
+        <location filename="../src/MainWindow.cpp" line="584"/>
+        <source>Opening %1</source>
+        <translation>Avataan kohdetta %1</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="597"/>
         <source>Do you want to exit %1 with a download in progress?</source>
         <translation>Tahdotko lopettaa vaikka %1 lataus(ta) on kesken?</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="598"/>
         <source>If you close %1 now, this download will be cancelled.</source>
         <translation>Jos suljet %1n nyt niin tämä lataus keskeytetään.</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="601"/>
         <source>Close and cancel download</source>
         <translation>Sulje ja keskeytä lataus</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="602"/>
         <source>Wait for download to finish</source>
         <translation>Odota latauksen valmistumista</translation>
     </message>
     <message>
-        <source>Downloads complete</source>
-        <translation>Lataukset ovat valmistuneet</translation>
+        <location filename="../src/MainWindow.cpp" line="635"/>
+        <source>Fatal error: %1</source>
+        <translation>Kohtalokas virhe: %1</translation>
     </message>
     <message>
-        <source>&amp;Clear recent searches</source>
-        <translation type="unfinished"></translation>
+        <location filename="../src/MainWindow.cpp" line="637"/>
+        <source>Error: %1</source>
+        <translation>Virhe: %1</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="660"/>
+        <source>&amp;Play</source>
+        <translation>&amp;Toista</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="661"/>
+        <source>Resume playback</source>
+        <translation>Jatka toistoa</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="751"/>
+        <source>Exit &amp;Full Screen</source>
+        <translation>Poistu &amp;kokoruudun tilasta</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="834"/>
+        <source>Remaining time: %1</source>
+        <translation>Aikaa jäljellä: %1</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="892"/>
+        <source>Volume at %1%</source>
+        <translation>Äänentaso: %1%</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="898"/>
+        <source>Volume is muted</source>
+        <translation>Ääni on mykistetty</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="901"/>
+        <source>Volume is unmuted</source>
+        <translation>Ääni ei ole mykistetty</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="908"/>
+        <source>Maximum video definition set to %1</source>
+        <translation>Korkein videonlaatu on rajoitettu tarkkuteen %1</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="944"/>
+        <source>Your privacy is now safe</source>
+        <translation>Yksityisyytesi on nyt turvattu</translation>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="960"/>
+        <source>Downloads complete</source>
+        <translation>Lataukset ovat valmistuneet</translation>
     </message>
 </context>
 <context>
     <name>MediaView</name>
     <message>
+        <location filename="../src/MediaView.cpp" line="33"/>
         <source>Most relevant</source>
         <translation>Osuvin</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="40"/>
         <source>Most recent</source>
         <translation>Viimeisin</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="47"/>
         <source>Most viewed</source>
         <translation>Katsotuin</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="489"/>
         <source>You can now paste the YouTube link into another application</source>
         <translation>Voit nyt liittää YouTube-linkin johonkin toiseen sovellukseen</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="497"/>
         <source>You can now paste the video stream URL into another application</source>
         <translation>Voit nyt liittää videovirran osoitteen (URL) johonkin toiseen sovellukseen</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="498"/>
         <source>The link will be valid only for a limited time.</source>
         <translation>Osoite on käytössä vain rajoitetun ajan.</translation>
     </message>
     <message>
-        <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation type="obsolete">Nyt pyörii &quot;%1&quot;</translation>
-    </message>
-    <message>
+        <location filename="../src/MediaView.cpp" line="594"/>
         <source>This is just the demo version of %1.</source>
         <translation>Tämä on vain %1n kokeiluversio.</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="595"/>
         <source>It allows you to test the application and see if it works for you.</source>
         <translation>Voit kokeilla ohjelmaa nähdäksesi että toimiiko se.</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="598"/>
         <source>Continue</source>
         <translation>Jatka</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="599"/>
         <source>Get the full version</source>
         <translation>Hanki täysi versio</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="625"/>
         <source>Downloading %1</source>
         <translation>Ladataan %1ta/tä</translation>
     </message>
@@ -545,6 +662,7 @@
 <context>
     <name>NetworkAccess</name>
     <message>
+        <location filename="../src/networkaccess.cpp" line="258"/>
         <source>Network error: %1</source>
         <translation>Verkkovirhe: %1</translation>
     </message>
@@ -552,53 +670,60 @@
 <context>
     <name>PrettyItemDelegate</name>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="156"/>
         <source>%1 views</source>
         <translation>Katsottu %1 kertaa</translation>
     </message>
     <message>
-        <source>%1 of %2 (%3) ? %4</source>
-        <translation type="obsolete">%1  %2 (%3)sta ? %4</translation>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="286"/>
+        <source>%1 of %2 (%3) — %4</source>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="293"/>
         <source>Preparing</source>
         <translation>Valmistellaan</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="295"/>
         <source>Failed</source>
         <translation>Epäonnistui</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="297"/>
         <source>Completed</source>
         <translation>Valmis</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="299"/>
         <source>Stopped</source>
         <translation>Pysäytetty</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="335"/>
         <source>Stop downloading</source>
         <translation>Pysäytä lataus</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="345"/>
         <source>Show in %1</source>
         <translation>Avaa %1ssa/ssä</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="347"/>
         <source>Open parent folder</source>
         <translation>Avaa yläkansio</translation>
     </message>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="356"/>
         <source>Restart downloading</source>
         <translation>Käynnistä lataus uudelleen</translation>
     </message>
-    <message>
-        <source>%1 of %2 (%3) — %4</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
     <message>
+        <location filename="../src/searchlineedit.cpp" line="177"/>
         <source>Search</source>
         <translation>Etsi</translation>
     </message>
@@ -606,64 +731,73 @@
 <context>
     <name>SearchView</name>
     <message>
+        <location filename="../src/SearchView.cpp" line="74"/>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
         <translation>Tervetuloa &lt;a href=&apos;%1&apos;&gt;%2en&lt;/a&gt;</translation>
     </message>
     <message>
-        <source>Enter a keyword to start watching videos.</source>
-        <translation type="obsolete">Anna hakusana aloittaaksesi videoiden katselu.</translation>
+        <location filename="../src/SearchView.cpp" line="41"/>
+        <source>Get the full version</source>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/SearchView.cpp" line="88"/>
+        <source>Enter</source>
+        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="93"/>
+        <source>a keyword</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="94"/>
+        <source>a channel</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="99"/>
+        <source>to start watching videos.</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="124"/>
         <source>Watch</source>
         <translation>Katso</translation>
     </message>
     <message>
+        <location filename="../src/SearchView.cpp" line="141"/>
         <source>Recent keywords</source>
         <translation>Viimeisimmät hakusanat</translation>
     </message>
     <message>
+        <location filename="../src/SearchView.cpp" line="159"/>
+        <source>Recent channels</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="358"/>
         <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
         <translation>Uusi versio %1sta on saatavilla. &lt;a href=&apos;%2&apos;&gt;Päivitäthän versioon %3&lt;/a&gt;</translation>
     </message>
     <message>
+        <location filename="../src/SearchView.h" line="35"/>
         <source>Make yourself comfortable</source>
         <translation>Tee olosi kotoisaksi</translation>
     </message>
-    <message>
-        <source>Get the full version</source>
-        <translation type="unfinished">Hanki täysi versio</translation>
-    </message>
-    <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>a keyword</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>a channel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Recent channels</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>Video</name>
     <message>
+        <location filename="../src/video.cpp" line="186"/>
+        <source>Cannot get video stream for %1</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/video.cpp" line="204"/>
         <source>Network error: %1 for %2</source>
         <translation>Verkkovirhe: &quot;%1&quot; &quot;%2&quot;lle</translation>
     </message>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
