@@ -1,58 +1,69 @@
-<?xml version="1.0" encoding="utf-8"?>
-<!DOCTYPE TS>
-<TS version="2.0">
+<?xml version="1.0" ?><!DOCTYPE TS><TS language="hr_HR" version="2.0">
 <defaultcodec>UTF-8</defaultcodec>
 <context>
     <name>AboutView</name>
     <message>
+        <location filename="../src/AboutView.cpp" line="21"/>
         <source>There&apos;s life outside the browser!</source>
         <translation>Postoji život izvan web preglednika!</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="22"/>
         <source>Version %1</source>
         <translation>Verzija %1</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="25"/>
         <source>%1 is Free Software but its development takes precious time.</source>
         <translation>%1 je besplatan program ali njegov razvoj zahtijeva dosta dragocjenog vremena.</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="26"/>
         <source>Please &lt;a href=&apos;%1&apos;&gt;donate&lt;/a&gt; to support the continued development of %2.</source>
         <translation>Molimo Vas da &lt;a href=&apos;%1&apos;&gt;donirate pomoću PayPala&lt;/a&gt; kako biste osigurali kontinuirani razvoj %2 programa. </translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="29"/>
         <source>Report bugs and send in your ideas to %1</source>
         <translation>Prijavite greške te šaljite svoje ideje i prijedloge na %1</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="33"/>
         <source>Icon designed by %1.</source>
         <translation>Ikonu je dizajnirao %1.</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="34"/>
         <source>Compact mode contributed by %1.</source>
         <translation>Kompaktni način prikaza omogućio je %1.</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="35"/>
         <source>HTTP proxy support contributed by %1.</source>
         <translation>HTTP proxy podršku omogućio je %1.</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="38"/>
         <source>Translated by %1</source>
         <translation>Minitube su preveli: %1</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="66"/>
         <source>Released under the &lt;a href=&apos;%1&apos;&gt;GNU General Public License&lt;/a&gt;</source>
         <translation>Program je objavljen pod &lt;a href=&apos;%1&apos;&gt;GNU General Public Licencom&lt;/a&gt;</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.cpp" line="78"/>
         <source>&amp;Close</source>
         <translation>&amp;Zatvori</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.h" line="18"/>
         <source>About</source>
         <translation>O programu</translation>
     </message>
     <message>
+        <location filename="../src/AboutView.h" line="20"/>
         <source>What you always wanted to know about %1 and never dared to ask</source>
         <translation>Sve što ste željeli znati o %1, a niste se usudili pitati</translation>
     </message>
@@ -60,6 +71,7 @@
 <context>
     <name>ClearButton</name>
     <message>
+        <location filename="../src/searchlineedit.cpp" line="56"/>
         <source>Clear</source>
         <translation>Očisti</translation>
     </message>
@@ -67,163 +79,198 @@
 <context>
     <name>DownloadItem</name>
     <message>
+        <location filename="../src/downloaditem.cpp" line="295"/>
         <source>bytes</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="298"/>
         <source>KB</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="301"/>
         <source>MB</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="317"/>
         <source>bytes/sec</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="320"/>
         <source>KB/sec</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="323"/>
         <source>MB/sec</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="329"/>
         <source>seconds</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="332"/>
         <source>minutes</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/downloaditem.cpp" line="335"/>
         <source>%4 %5 remaining</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
 </context>
 <context>
     <name>DownloadManager</name>
-    <message numerus="yes">
-        <source>%n Download(s)</source>
-        <translation type="unfinished">
-            <numerusform></numerusform>
-        </translation>
-    </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="47"/>
         <source>This is just the demo version of %1.</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="49"/>
         <source>It can only download videos shorter than %1 minutes so you can test the download functionality.</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="53"/>
         <source>Continue</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/downloadmanager.cpp" line="54"/>
         <source>Get the full version</source>
-        <translation type="unfinished"></translation>
+        <translation/>
+    </message>
+    <message numerus="yes">
+        <location filename="../src/downloadmanager.cpp" line="126"/>
+        <source>%n Download(s)</source>
+        <translation><numerusform></numerusform><numerusform></numerusform><numerusform></numerusform></translation>
     </message>
 </context>
 <context>
     <name>DownloadSettings</name>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="14"/>
         <source>Change location...</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="38"/>
         <source>Choose the download location</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="49"/>
         <source>Download location changed.</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="51"/>
         <source>Current downloads will still go in the previous location.</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/downloadsettings.cpp" line="63"/>
         <source>Downloading to: %1</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
 </context>
 <context>
     <name>DownloadView</name>
     <message>
+        <location filename="../src/downloadview.cpp" line="18"/>
+        <location filename="../src/downloadview.h" line="22"/>
         <source>Downloads</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
 </context>
 <context>
     <name>GlobalShortcuts</name>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="16"/>
         <source>Play</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="17"/>
         <source>Pause</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="18"/>
         <source>Play/Pause</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="19"/>
         <source>Stop</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="20"/>
         <source>Stop playing after current track</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="21"/>
         <source>Next track</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="22"/>
         <source>Previous track</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="23"/>
         <source>Increase volume</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="24"/>
         <source>Decrease volume</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="25"/>
         <source>Mute</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="26"/>
         <source>Seek forward</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/globalshortcuts.cpp" line="27"/>
         <source>Seek backward</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
 </context>
 <context>
     <name>ListModel</name>
     <message>
+        <location filename="../src/ListModel.cpp" line="47"/>
         <source>Searching...</source>
         <translation>Tražim...</translation>
     </message>
     <message>
+        <location filename="../src/ListModel.cpp" line="48"/>
         <source>Show %1 More</source>
         <translation>Prikaži još %1 videa</translation>
     </message>
     <message>
+        <location filename="../src/ListModel.cpp" line="49"/>
         <source>No videos</source>
         <translation>Nema videa</translation>
     </message>
     <message>
+        <location filename="../src/ListModel.cpp" line="50"/>
         <source>No more videos</source>
         <translation>Nema više videa</translation>
     </message>
@@ -231,6 +278,7 @@
 <context>
     <name>LoadingWidget</name>
     <message>
+        <location filename="../src/loadingwidget.cpp" line="71"/>
         <source>Error</source>
         <translation>Pogreška</translation>
     </message>
@@ -238,312 +286,383 @@
 <context>
     <name>MainWindow</name>
     <message>
+        <location filename="../src/MainWindow.cpp" line="105"/>
         <source>&amp;Stop</source>
         <translation>&amp;Zaustavi</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="106"/>
         <source>Stop playback and go back to the search view</source>
         <translation>Zaustavi prikazivanje videa i vrati se na pretraživanje</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="112"/>
         <source>S&amp;kip</source>
         <translation>P&amp;reskoči</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="113"/>
         <source>Skip to the next video</source>
         <translation>Preskoči na slijedeći video</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="119"/>
+        <location filename="../src/MainWindow.cpp" line="644"/>
         <source>&amp;Pause</source>
         <translation>&amp;Pauza</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="120"/>
+        <location filename="../src/MainWindow.cpp" line="645"/>
         <source>Pause playback</source>
         <translation>Pauziraj izvođenje videa</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="126"/>
+        <location filename="../src/MainWindow.cpp" line="728"/>
         <source>&amp;Full Screen</source>
         <translation>&amp;Cijeli ekran</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="127"/>
         <source>Go full screen</source>
         <translation>Gledaj video preko cijelog ekrana</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="136"/>
         <source>&amp;Compact mode</source>
         <translation>&amp;Kompaktni način</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="137"/>
         <source>Hide the playlist and the toolbar</source>
         <translation>Sakrij listu izvođenja i alatnu traku</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="145"/>
         <source>Open the &amp;YouTube page</source>
         <translation>&amp;YouTube web stranica</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="146"/>
         <source>Go to the YouTube video page and pause playback</source>
         <translation>Otvori video na YouTube web stranici i pauziraj izvođenje videa</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="152"/>
         <source>Copy the YouTube &amp;link</source>
         <translation>Kopiraj &amp;YouTube poveznicu</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="153"/>
         <source>Copy the current video YouTube link to the clipboard</source>
         <translation>Kopiraj YouTube poveznicu videa koji se izvodi u međuspremnik</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="159"/>
         <source>Copy the video stream &amp;URL</source>
         <translation>Kopiraj web &amp;adresu videa</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="160"/>
         <source>Copy the current video stream URL to the clipboard</source>
         <translation>Kopiraj web adresu videa koji se izvodi u međuspremnik</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="166"/>
         <source>&amp;Remove</source>
         <translation>&amp;Ukloni</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="167"/>
         <source>Remove the selected videos from the playlist</source>
         <translation>Ukloni označene video isječke sa liste izvođenja</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="173"/>
         <source>Move &amp;Up</source>
         <translation>Premjesti &amp;gore</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="174"/>
         <source>Move up the selected videos in the playlist</source>
         <translation>Premjesti odabrane video isječke prema gore u listi izvođenja</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="180"/>
         <source>Move &amp;Down</source>
         <translation>Premjesti &amp;dolje</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="181"/>
         <source>Move down the selected videos in the playlist</source>
         <translation>Premjesti odabrane video isječke prema dolje u listi izvođenja</translation>
     </message>
     <message>
-        <source>&amp;Clear recent keywords</source>
-        <translation type="obsolete">&amp;Obriši povijest pretraživanja</translation>
+        <location filename="../src/MainWindow.cpp" line="187"/>
+        <source>&amp;Clear recent searches</source>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="192"/>
         <source>Clear the search history. Cannot be undone.</source>
         <translation>Obriši povijest pretraživanja. Ova akcija se ne može poništiti.</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="197"/>
         <source>&amp;Quit</source>
         <translation>&amp;Zatvori program</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="199"/>
         <source>Ctrl+Q</source>
         <translation>Ctrl+Q</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="200"/>
         <source>Bye</source>
         <translation>Doviđenja</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="204"/>
         <source>&amp;Website</source>
         <translation>&amp;Web stranica</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="206"/>
         <source>%1 on the Web</source>
         <translation>%1 na internetu</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="210"/>
         <source>Make a &amp;donation</source>
         <translation>Napravi &amp;donaciju</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="211"/>
         <source>Please support the continued development of %1</source>
         <translation>Molimo Vas da podržite kontinuirani razvoj %1</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="215"/>
         <source>&amp;About</source>
         <translation>&amp;O programu</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="217"/>
         <source>Info about %1</source>
         <translation>Informacije o %1</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="225"/>
         <source>Search</source>
         <translation>Traži</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="244"/>
         <source>Mute volume</source>
         <translation>Isključi zvuk</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="246"/>
         <source>Ctrl+M</source>
         <translation>Ctrl+M</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="277"/>
+        <location filename="../src/MainWindow.cpp" line="959"/>
+        <source>&amp;Downloads</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="278"/>
+        <source>Show details about video downloads</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="286"/>
+        <source>&amp;Download</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="287"/>
+        <source>Download the current video</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="328"/>
         <source>&amp;Application</source>
         <translation>&amp;Program</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="336"/>
         <source>&amp;Playlist</source>
         <translation>&amp;Lista izvođenja</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="343"/>
         <source>&amp;Video</source>
         <translation>&amp;Video</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="362"/>
         <source>&amp;Help</source>
         <translation>&amp;Pomoć</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="439"/>
         <source>Press %1 to raise the volume, %2 to lower it</source>
         <translation>Pritisni %1 za pojačavanje zvuka, %2 za stišavanje</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="578"/>
+        <location filename="../src/MainWindow.cpp" line="584"/>
         <source>Opening %1</source>
         <translation>Otvaram %1</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="597"/>
+        <source>Do you want to exit %1 with a download in progress?</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="598"/>
+        <source>If you close %1 now, this download will be cancelled.</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="601"/>
+        <source>Close and cancel download</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="602"/>
+        <source>Wait for download to finish</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/MainWindow.cpp" line="635"/>
         <source>Fatal error: %1</source>
         <translation>Fatalna pogreška: %1</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="637"/>
         <source>Error: %1</source>
         <translation>Pogreška: %1</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="660"/>
         <source>&amp;Play</source>
         <translation>&amp;Pokreni</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="661"/>
         <source>Resume playback</source>
         <translation>Nastavi izvođenje</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="751"/>
         <source>Exit &amp;Full Screen</source>
         <translation>&amp;Prekini prikaz preko cijelog ekrana</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="834"/>
         <source>Remaining time: %1</source>
         <translation>Preostalo vrijeme: %1</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="892"/>
         <source>Volume at %1%</source>
         <translation>Jačina zvuka %1%</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="898"/>
         <source>Volume is muted</source>
         <translation>Zvuk je isključen</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="901"/>
         <source>Volume is unmuted</source>
         <translation>Zvuk je uključen</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="908"/>
         <source>Maximum video definition set to %1</source>
         <translation>Maksimalna video rezolucija je postavljena na %1</translation>
     </message>
     <message>
+        <location filename="../src/MainWindow.cpp" line="944"/>
         <source>Your privacy is now safe</source>
         <translation>Vaša privatnost je sada sigurna</translation>
     </message>
     <message>
-        <source>&amp;Downloads</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show details about video downloads</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Download</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Download the current video</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Do you want to exit %1 with a download in progress?</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>If you close %1 now, this download will be cancelled.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Close and cancel download</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Wait for download to finish</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
+        <location filename="../src/MainWindow.cpp" line="960"/>
         <source>Downloads complete</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>&amp;Clear recent searches</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
 </context>
 <context>
     <name>MediaView</name>
     <message>
+        <location filename="../src/MediaView.cpp" line="33"/>
         <source>Most relevant</source>
         <translation>Najznačajniji</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="40"/>
         <source>Most recent</source>
         <translation>Najnoviji</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="47"/>
         <source>Most viewed</source>
         <translation>Najgledaniji</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="489"/>
         <source>You can now paste the YouTube link into another application</source>
         <translation>Možete zalijepiti YouTube poveznicu u drugu aplikaciju</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="497"/>
         <source>You can now paste the video stream URL into another application</source>
         <translation>Možete zalijepiti web adresu video isječka u drugu aplikaciju</translation>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="498"/>
         <source>The link will be valid only for a limited time.</source>
         <translation>Poveznica će vrijediti samo neko vrijeme.</translation>
     </message>
     <message>
-        <source>You&apos;re watching &quot;%1&quot;</source>
-        <translation type="obsolete">Gledate &quot;%1&quot;</translation>
-    </message>
-    <message>
+        <location filename="../src/MediaView.cpp" line="594"/>
         <source>This is just the demo version of %1.</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="595"/>
         <source>It allows you to test the application and see if it works for you.</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="598"/>
         <source>Continue</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="599"/>
         <source>Get the full version</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/MediaView.cpp" line="625"/>
         <source>Downloading %1</source>
-        <translation type="unfinished"></translation>
+        <translation/>
     </message>
 </context>
 <context>
     <name>NetworkAccess</name>
     <message>
+        <location filename="../src/networkaccess.cpp" line="258"/>
         <source>Network error: %1</source>
         <translation>Greška na mreži: %1</translation>
     </message>
@@ -551,49 +670,60 @@
 <context>
     <name>PrettyItemDelegate</name>
     <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="156"/>
         <source>%1 views</source>
         <translation>%1 pregleda</translation>
     </message>
     <message>
-        <source>Preparing</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Failed</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Completed</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Stopped</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Stop downloading</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Show in %1</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Open parent folder</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Restart downloading</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="286"/>
         <source>%1 of %2 (%3) — %4</source>
-        <translation type="unfinished"></translation>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="293"/>
+        <source>Preparing</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="295"/>
+        <source>Failed</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="297"/>
+        <source>Completed</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="299"/>
+        <source>Stopped</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="335"/>
+        <source>Stop downloading</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="345"/>
+        <source>Show in %1</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="347"/>
+        <source>Open parent folder</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/playlist/PrettyItemDelegate.cpp" line="356"/>
+        <source>Restart downloading</source>
+        <translation/>
     </message>
 </context>
 <context>
     <name>SearchLineEdit</name>
     <message>
+        <location filename="../src/searchlineedit.cpp" line="177"/>
         <source>Search</source>
         <translation>Traži</translation>
     </message>
@@ -601,64 +731,73 @@
 <context>
     <name>SearchView</name>
     <message>
+        <location filename="../src/SearchView.cpp" line="74"/>
         <source>Welcome to &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</source>
         <translation>Dobrodošli na &lt;a href=&apos;%1&apos;&gt;%2&lt;/a&gt;,</translation>
     </message>
     <message>
-        <source>Enter a keyword to start watching videos.</source>
-        <translation type="obsolete">Unesite ključnu riječ za početak gledanja videa.</translation>
+        <location filename="../src/SearchView.cpp" line="41"/>
+        <source>Get the full version</source>
+        <translation/>
     </message>
     <message>
+        <location filename="../src/SearchView.cpp" line="88"/>
+        <source>Enter</source>
+        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="93"/>
+        <source>a keyword</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="94"/>
+        <source>a channel</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="99"/>
+        <source>to start watching videos.</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="124"/>
         <source>Watch</source>
         <translation>Gledaj</translation>
     </message>
     <message>
+        <location filename="../src/SearchView.cpp" line="141"/>
         <source>Recent keywords</source>
         <translation>Nedavno gledano</translation>
     </message>
     <message>
+        <location filename="../src/SearchView.cpp" line="159"/>
+        <source>Recent channels</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/SearchView.cpp" line="358"/>
         <source>A new version of %1 is available. Please &lt;a href=&apos;%2&apos;&gt;update to version %3&lt;/a&gt;</source>
         <translation>Nova verzija %1 je dostupna. Molimo &lt;a href=&apos;%2&apos;&gt;nadogradite na verziju %3&lt;/a&gt;</translation>
     </message>
     <message>
+        <location filename="../src/SearchView.h" line="35"/>
         <source>Make yourself comfortable</source>
         <translation>Udobno se smjestite i opustite se</translation>
     </message>
-    <message>
-        <source>Get the full version</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Enter</source>
-        <extracomment>&quot;Enter&quot;, as in &quot;type&quot;. The whole frase says: &quot;Enter a keyword to start watching videos&quot;</extracomment>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>a keyword</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>a channel</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>to start watching videos.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Recent channels</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
 <context>
     <name>Video</name>
     <message>
+        <location filename="../src/video.cpp" line="186"/>
+        <source>Cannot get video stream for %1</source>
+        <translation/>
+    </message>
+    <message>
+        <location filename="../src/video.cpp" line="204"/>
         <source>Network error: %1 for %2</source>
         <translation>Greška na mreži: %1 za %2</translation>
     </message>
-    <message>
-        <source>Cannot get video stream for %1</source>
-        <translation type="unfinished"></translation>
-    </message>
 </context>
-</TS>
+</TS>
\ No newline at end of file
