@@ -9,8 +9,8 @@
 #ifdef Q_WS_X11
 #include "gnomeglobalshortcutbackend.h"
 #endif
-#ifdef APP_MAC
-// #include "local/mac/mac_startup.h"
+#ifdef APP_MAC_STORE
+#include "local/mac/mac_startup.h"
 #endif
 #include "downloadmanager.h"
 #include "youtubesuggest.h"
@@ -89,13 +89,23 @@ MainWindow::~MainWindow() {
 }
 
 bool MainWindow::eventFilter(QObject *obj, QEvent *event) {
+    if (event->type() == QEvent::MouseMove && this->m_fullscreen) {
+        QMouseEvent *mouseEvent = static_cast<QMouseEvent*> (event);
+        int x = mouseEvent->pos().x();
+        int y = mouseEvent->pos().y();
+
+        if (y < 0 && (obj == this->mainToolBar || !(y <= 10-this->mainToolBar->height() && y >= 0-this->mainToolBar->height() )))
+           this->mainToolBar->setVisible(false);
+        if (x < 0)
+            this->mediaView->setPlaylistVisible(false);
+    }
+
     if (event->type() == QEvent::ToolTip) {
         // kill tooltips
         return true;
-    } else {
-        // standard event processing
-        return QObject::eventFilter(obj, event);
     }
+    // standard event processing
+    return QObject::eventFilter(obj, event);
 }
 
 void MainWindow::createActions() {
@@ -474,7 +484,11 @@ void MainWindow::readSettings() {
     restoreGeometry(settings.value("geometry").toByteArray());
 #ifdef APP_MAC
     if (!isMaximized())
+#ifdef QT_MAC_USE_COCOA
+        move(x(), y() + 10);
+#else
         move(x(), y() + mainToolBar->height() + 8);
+#endif
 #endif
     setDefinitionMode(settings.value("definition", VideoDefinition::getDefinitionNames().first()).toString());
     audioOutput->setVolume(settings.value("volume", 1).toDouble());
@@ -546,7 +560,7 @@ void MainWindow::showWidget ( QWidget* widget ) {
     QWidget *oldWidget = views->currentWidget();
     views->setCurrentWidget(widget);
 
-#ifdef APP_MAC
+#if defined(APP_MAC) || defined(APP_WIN)
     // crossfade only on OSX
     // where we can be sure of video performance
     fadeInWidget(oldWidget, widget);
