@@ -5,7 +5,14 @@ VideoAreaWidget::VideoAreaWidget(QWidget *parent) : QWidget(parent) {
     QBoxLayout *vLayout = new QVBoxLayout(this);
     vLayout->setMargin(0);
     vLayout->setSpacing(0);
-    
+
+#ifdef APP_WIN
+    QPalette p = palette();
+    p.setBrush(QPalette::Window, Qt::black);
+    setPalette(p);
+    setAutoFillBackground(true);
+#endif
+
     // hidden message widget
     messageLabel = new QLabel(this);
     messageLabel->setOpenExternalLinks(true);
